[gtk+] Bug 596125 — Property string fixes



commit 3eb197b51fbcfab20abc618c7081bb400844996e
Author: Philip Withnall <philip tecnocode co uk>
Date:   Tue Aug 10 09:23:49 2010 +0100

    Bug 596125 â?? Property string fixes

 gtk/gtkcellrendererspin.c |    2 +-
 gtk/gtkcellrenderertext.c |    2 +-
 gtk/gtkcolorbutton.c      |    2 +-
 gtk/gtkentry.c            |    4 ++--
 gtk/gtkfilechooser.c      |    2 +-
 gtk/gtknotebook.c         |   10 +++++-----
 gtk/gtkplug.c             |    2 +-
 gtk/gtkprintunixdialog.c  |    2 +-
 gtk/gtkprogressbar.c      |   12 ++++++------
 gtk/gtkspinbutton.c       |    2 +-
 gtk/gtkstatusicon.c       |    6 +++---
 gtk/gtktoggleaction.c     |    4 ++--
 gtk/gtktogglebutton.c     |    2 +-
 gtk/gtktoggletoolbutton.c |    4 ++--
 gtk/gtkwidget.c           |    4 ++--
 15 files changed, 30 insertions(+), 30 deletions(-)
---
diff --git a/gtk/gtkcellrendererspin.c b/gtk/gtkcellrendererspin.c
index 536152d..b7f589e 100644
--- a/gtk/gtkcellrendererspin.c
+++ b/gtk/gtkcellrendererspin.c
@@ -89,7 +89,7 @@ gtk_cell_renderer_spin_class_init (GtkCellRendererSpinClass *klass)
 				   PROP_ADJUSTMENT,
 				   g_param_spec_object ("adjustment",
 							P_("Adjustment"),
-							P_("The adjustment that holds the value of the spinbutton."),
+							P_("The adjustment that holds the value of the spin button"),
 							GTK_TYPE_ADJUSTMENT,
 							GTK_PARAM_READWRITE));
 
diff --git a/gtk/gtkcellrenderertext.c b/gtk/gtkcellrenderertext.c
index 46c5211..435bb3d 100644
--- a/gtk/gtkcellrenderertext.c
+++ b/gtk/gtkcellrenderertext.c
@@ -238,7 +238,7 @@ gtk_cell_renderer_text_class_init (GtkCellRendererTextClass *class)
                                    PROP_SINGLE_PARAGRAPH_MODE,
                                    g_param_spec_boolean ("single-paragraph-mode",
                                                          P_("Single Paragraph Mode"),
-                                                         P_("Whether or not to keep all text in a single paragraph"),
+                                                         P_("Whether to keep all text in a single paragraph"),
                                                          FALSE,
                                                          GTK_PARAM_READWRITE));
 
diff --git a/gtk/gtkcolorbutton.c b/gtk/gtkcolorbutton.c
index a164caf..24bb047 100644
--- a/gtk/gtkcolorbutton.c
+++ b/gtk/gtkcolorbutton.c
@@ -157,7 +157,7 @@ gtk_color_button_class_init (GtkColorButtonClass *klass)
   g_object_class_install_property (gobject_class,
                                    PROP_USE_ALPHA,
                                    g_param_spec_boolean ("use-alpha", P_("Use alpha"), 
-                                                         P_("Whether or not to give the color an alpha value"),
+                                                         P_("Whether to give the color an alpha value"),
                                                          FALSE,
                                                          GTK_PARAM_READWRITE));
 
diff --git a/gtk/gtkentry.c b/gtk/gtkentry.c
index fc0cf13..723098e 100644
--- a/gtk/gtkentry.c
+++ b/gtk/gtkentry.c
@@ -832,8 +832,8 @@ gtk_entry_class_init (GtkEntryClass *class)
   g_object_class_install_property (gobject_class,
                                    PROP_INVISIBLE_CHAR_SET,
                                    g_param_spec_boolean ("invisible-char-set",
-                                                         P_("Invisible char set"),
-                                                         P_("Whether the invisible char has been set"),
+                                                         P_("Invisible character set"),
+                                                         P_("Whether the invisible character has been set"),
                                                          FALSE,
                                                          GTK_PARAM_READWRITE));
 
diff --git a/gtk/gtkfilechooser.c b/gtk/gtkfilechooser.c
index 28f9f0c..3dbcfaa 100644
--- a/gtk/gtkfilechooser.c
+++ b/gtk/gtkfilechooser.c
@@ -838,7 +838,7 @@ gtk_file_chooser_class_init (gpointer g_iface)
    */
   g_object_interface_install_property (g_iface,
 				       g_param_spec_boolean ("create-folders",
-							     P_("Allow folders creation"),
+							     P_("Allow folder creation"),
 							     P_("Whether a file chooser not in open mode "
 								"will offer the user to create new folders."),
 							     TRUE,
diff --git a/gtk/gtknotebook.c b/gtk/gtknotebook.c
index 8fce955..44d1c9a 100644
--- a/gtk/gtknotebook.c
+++ b/gtk/gtknotebook.c
@@ -618,14 +618,14 @@ gtk_notebook_class_init (GtkNotebookClass *class)
 				   PROP_SHOW_TABS,
 				   g_param_spec_boolean ("show-tabs",
  							 P_("Show Tabs"),
- 							 P_("Whether tabs should be shown or not"),
+							 P_("Whether tabs should be shown"),
  							 TRUE,
  							 GTK_PARAM_READWRITE));
   g_object_class_install_property (gobject_class,
 				   PROP_SHOW_BORDER,
 				   g_param_spec_boolean ("show-border",
  							 P_("Show Border"),
- 							 P_("Whether the border should be shown or not"),
+							 P_("Whether the border should be shown"),
  							 TRUE,
  							 GTK_PARAM_READWRITE));
   g_object_class_install_property (gobject_class,
@@ -682,14 +682,14 @@ gtk_notebook_class_init (GtkNotebookClass *class)
 					      CHILD_PROP_TAB_EXPAND,
 					      g_param_spec_boolean ("tab-expand", 
 								    P_("Tab expand"), 
-								    P_("Whether to expand the child's tab or not"),
+								    P_("Whether to expand the child's tab"),
 								    FALSE,
 								    GTK_PARAM_READWRITE));
   gtk_container_class_install_child_property (container_class,
 					      CHILD_PROP_TAB_FILL,
 					      g_param_spec_boolean ("tab-fill", 
 								    P_("Tab fill"), 
-								    P_("Whether the child's tab should fill the allocated area or not"),
+								    P_("Whether the child's tab should fill the allocated area"),
 								    TRUE,
 								    GTK_PARAM_READWRITE));
   gtk_container_class_install_child_property (container_class,
@@ -703,7 +703,7 @@ gtk_notebook_class_init (GtkNotebookClass *class)
 					      CHILD_PROP_REORDERABLE,
 					      g_param_spec_boolean ("reorderable",
 								    P_("Tab reorderable"),
-								    P_("Whether the tab is reorderable by user action or not"),
+								    P_("Whether the tab is reorderable by user action"),
 								    FALSE,
 								    GTK_PARAM_READWRITE));
   gtk_container_class_install_child_property (container_class,
diff --git a/gtk/gtkplug.c b/gtk/gtkplug.c
index f1e2a19..e5c2f0d 100644
--- a/gtk/gtkplug.c
+++ b/gtk/gtkplug.c
@@ -167,7 +167,7 @@ gtk_plug_class_init (GtkPlugClass *class)
 				   PROP_EMBEDDED,
 				   g_param_spec_boolean ("embedded",
 							 P_("Embedded"),
-							 P_("Whether or not the plug is embedded"),
+							 P_("Whether the plug is embedded"),
 							 FALSE,
 							 GTK_PARAM_READABLE));
 
diff --git a/gtk/gtkprintunixdialog.c b/gtk/gtkprintunixdialog.c
index ba0d4ec..3b596f5 100644
--- a/gtk/gtkprintunixdialog.c
+++ b/gtk/gtkprintunixdialog.c
@@ -329,7 +329,7 @@ gtk_print_unix_dialog_class_init (GtkPrintUnixDialogClass *class)
   g_object_class_install_property (object_class,
                                    PROP_MANUAL_CAPABILITIES,
                                    g_param_spec_flags ("manual-capabilities",
-                                                       P_("Manual Capabilites"),
+                                                       P_("Manual Capabilities"),
                                                        P_("Capabilities the application can handle"),
                                                        GTK_TYPE_PRINT_CAPABILITIES,
                                                        0,
diff --git a/gtk/gtkprogressbar.c b/gtk/gtkprogressbar.c
index bea40f5..55a3cce 100644
--- a/gtk/gtkprogressbar.c
+++ b/gtk/gtkprogressbar.c
@@ -178,13 +178,13 @@ gtk_progress_bar_class_init (GtkProgressBarClass *class)
                                                       GTK_PARAM_READWRITE));
   gtk_widget_class_install_style_property (widget_class,
                                            g_param_spec_int ("xspacing",
-                                                             P_("XSpacing"),
+                                                             P_("X spacing"),
                                                              P_("Extra spacing applied to the width of a progress bar."),
                                                              0, G_MAXINT, 7,
                                                              G_PARAM_READWRITE));
   gtk_widget_class_install_style_property (widget_class,
                                            g_param_spec_int ("yspacing",
-                                                             P_("YSpacing"),
+                                                             P_("Y spacing"),
                                                              P_("Extra spacing applied to the height of a progress bar."),
                                                              0, G_MAXINT, 7,
                                                              G_PARAM_READWRITE));
@@ -198,7 +198,7 @@ gtk_progress_bar_class_init (GtkProgressBarClass *class)
    */
   gtk_widget_class_install_style_property (widget_class,
                                            g_param_spec_int ("min-horizontal-bar-width",
-                                                             P_("Min horizontal bar width"),
+                                                             P_("Minimum horizontal bar width"),
                                                              P_("The minimum horizontal width of the progress bar"),
                                                              1, G_MAXINT, MIN_HORIZONTAL_BAR_WIDTH,
                                                              G_PARAM_READWRITE));
@@ -211,7 +211,7 @@ gtk_progress_bar_class_init (GtkProgressBarClass *class)
    */
   gtk_widget_class_install_style_property (widget_class,
                                            g_param_spec_int ("min-horizontal-bar-height",
-                                                             P_("Min horizontal bar height"),
+                                                             P_("Minimum horizontal bar height"),
                                                              P_("Minimum horizontal height of the progress bar"),
                                                              1, G_MAXINT, MIN_HORIZONTAL_BAR_HEIGHT,
                                                              G_PARAM_READWRITE));
@@ -224,7 +224,7 @@ gtk_progress_bar_class_init (GtkProgressBarClass *class)
    */
   gtk_widget_class_install_style_property (widget_class,
                                            g_param_spec_int ("min-vertical-bar-width",
-                                                             P_("Min vertical bar width"),
+                                                             P_("Minimum vertical bar width"),
                                                              P_("The minimum vertical width of the progress bar"),
                                                              1, G_MAXINT, MIN_VERTICAL_BAR_WIDTH,
                                                              G_PARAM_READWRITE));
@@ -237,7 +237,7 @@ gtk_progress_bar_class_init (GtkProgressBarClass *class)
    */
   gtk_widget_class_install_style_property (widget_class,
                                            g_param_spec_int ("min-vertical-bar-height",
-                                                             P_("Min vertical bar height"),
+                                                             P_("Minimum vertical bar height"),
                                                              P_("The minimum vertical height of the progress bar"),
                                                              1, G_MAXINT, MIN_VERTICAL_BAR_HEIGHT,
                                                              G_PARAM_READWRITE));
diff --git a/gtk/gtkspinbutton.c b/gtk/gtkspinbutton.c
index 727fa59..330f327 100644
--- a/gtk/gtkspinbutton.c
+++ b/gtk/gtkspinbutton.c
@@ -229,7 +229,7 @@ gtk_spin_button_class_init (GtkSpinButtonClass *class)
                                    PROP_ADJUSTMENT,
                                    g_param_spec_object ("adjustment",
                                                         P_("Adjustment"),
-                                                        P_("The adjustment that holds the value of the spinbutton"),
+                                                        P_("The adjustment that holds the value of the spin button"),
                                                         GTK_TYPE_ADJUSTMENT,
                                                         GTK_PARAM_READWRITE));
   
diff --git a/gtk/gtkstatusicon.c b/gtk/gtkstatusicon.c
index 7d6facc..2f04018 100644
--- a/gtk/gtkstatusicon.c
+++ b/gtk/gtkstatusicon.c
@@ -289,7 +289,7 @@ gtk_status_icon_class_init (GtkStatusIconClass *class)
 				   PROP_BLINKING,
 				   g_param_spec_boolean ("blinking",
 							 P_("Blinking"),
-							 P_("Whether or not the status icon is blinking"),
+							 P_("Whether the status icon is blinking"),
 							 FALSE,
 							 GTK_PARAM_READWRITE));
 
@@ -297,7 +297,7 @@ gtk_status_icon_class_init (GtkStatusIconClass *class)
 				   PROP_VISIBLE,
 				   g_param_spec_boolean ("visible",
 							 P_("Visible"),
-							 P_("Whether or not the status icon is visible"),
+							 P_("Whether the status icon is visible"),
 							 TRUE,
 							 GTK_PARAM_READWRITE));
 
@@ -313,7 +313,7 @@ gtk_status_icon_class_init (GtkStatusIconClass *class)
 				   PROP_EMBEDDED,
 				   g_param_spec_boolean ("embedded",
 							 P_("Embedded"),
-							 P_("Whether or not the status icon is embedded"),
+							 P_("Whether the status icon is embedded"),
 							 FALSE,
 							 GTK_PARAM_READABLE));
 
diff --git a/gtk/gtktogglebutton.c b/gtk/gtktogglebutton.c
index e18edae..2ea40ac 100644
--- a/gtk/gtktogglebutton.c
+++ b/gtk/gtktogglebutton.c
@@ -113,7 +113,7 @@ gtk_toggle_button_class_init (GtkToggleButtonClass *class)
                                    PROP_ACTIVE,
                                    g_param_spec_boolean ("active",
 							 P_("Active"),
-							 P_("If the toggle button should be pressed in or not"),
+							 P_("If the toggle button should be pressed in"),
 							 FALSE,
 							 GTK_PARAM_READWRITE));
 
diff --git a/gtk/gtktoggletoolbutton.c b/gtk/gtktoggletoolbutton.c
index c632b7b..bf6a071 100644
--- a/gtk/gtktoggletoolbutton.c
+++ b/gtk/gtktoggletoolbutton.c
@@ -102,7 +102,7 @@ gtk_toggle_tool_button_class_init (GtkToggleToolButtonClass *klass)
   /**
    * GtkToggleToolButton:active:
    *
-   * If the toggle tool button should be pressed in or not.
+   * If the toggle tool button should be pressed in.
    *
    * Since: 2.8
    */
@@ -110,7 +110,7 @@ gtk_toggle_tool_button_class_init (GtkToggleToolButtonClass *klass)
                                    PROP_ACTIVE,
                                    g_param_spec_boolean ("active",
 							 P_("Active"),
-							 P_("If the toggle button should be pressed in or not"),
+							 P_("If the toggle button should be pressed in"),
 							 FALSE,
 							 GTK_PARAM_READWRITE));
 
diff --git a/gtk/gtkwidget.c b/gtk/gtkwidget.c
index 8d22c70..a859bf2 100644
--- a/gtk/gtkwidget.c
+++ b/gtk/gtkwidget.c
@@ -789,7 +789,7 @@ gtk_widget_class_init (GtkWidgetClass *klass)
   /**
    * GtkWidget:double-buffered
    *
-   * Whether or not the widget is double buffered.
+   * Whether the widget is double buffered.
    *
    * Since: 2.18
    */
@@ -797,7 +797,7 @@ gtk_widget_class_init (GtkWidgetClass *klass)
                                    PROP_DOUBLE_BUFFERED,
                                    g_param_spec_boolean ("double-buffered",
                                                          P_("Double Buffered"),
-                                                         P_("Whether or not the widget is double buffered"),
+                                                         P_("Whether the widget is double buffered"),
                                                          TRUE,
                                                          GTK_PARAM_READWRITE));
 



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/gtk/gtktoggleaction.c b/gtk/gtktoggleaction.c
index 86ec59b..525d462 100644
--- a/gtk/gtktoggleaction.c
+++ b/gtk/gtktoggleaction.c
@@ -123,7 +123,7 @@ gtk_toggle_action_class_init (GtkToggleActionClass *klass)
   /**
    * GtkToggleAction:active:
    *
    * If the toggle action should be active in or not.
    *
    * Since: 2.10
    */
@@ -131,7 +131,7 @@ gtk_toggle_action_class_init (GtkToggleActionClass *klass)
                                    PROP_ACTIVE,
                                    g_param_spec_boolean ("active",
                                                          P_("Active"),
-                                                         P_("If the toggle action should be active in or not"),
+                                                         P_("Whether the toggle action should be active"),
                                                          FALSE,
                                                          GTK_PARAM_READWRITE));
   /**
@@ -123,7 +123,7 @@ gtk_toggle_action_class_init (GtkToggleActionClass *klass)
    * GtkToggleAction:active:
    *
-   * If the toggle action should be active in or not.
+   * Whether the toggle action should be active.
    *
    * Since: 2.10